@@ -107,7 +107,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
     ],
     "bound_correction_COTN": [
         79.60197400323416,
-        9075.812942413004,
+        9075.81294241299,
         -443.0425148340509,
         -449.63233155751726,
         15.221583968074889,
@@ -122,7 +122,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
         -52.116212719435566,
         1017.7040292314994,
         72.00354123874057,
-        7.140121147903709,
+        7.140121147903702,
         34.24774851152607,
         -102.24646124346252,
         -543.698445859984,
@@ -133,7 +133,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
     ],
     "bound_correction_mirror": [
         79.60197400323416,
-        9075.812942413004,
+        9075.81294241299,
         -443.0425148340509,
         -449.63233155751726,
         15.221583968074889,
@@ -148,7 +148,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
         -52.116212719435566,
         1017.7040292314994,
         72.00354123874057,
-        7.140121147903709,
+        7.140121147903702,
         34.24774851152607,
         -102.24646124346252,
         -543.698445859984,
@@ -159,7 +159,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
     ],
     "bound_correction_saturate": [
         79.60197400323416,
-        9075.812942413004,
+        9075.81294241299,
         -443.0425148340509,
         -449.63233155751726,
         15.221583968074889,
@@ -174,7 +174,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
         -52.116212719435566,
         1017.7040292314994,
         72.00354123874057,
-        7.140121147903709,
+        7.140121147903702,
         34.24774851152607,
         -102.24646124346252,
         -543.698445859984,
@@ -185,7 +185,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
     ],
     "bound_correction_toroidal": [
         79.60197400323416,
-        9075.812942413004,
+        9075.81294241299,
         -443.0425148340509,
         -449.63233155751726,
         15.221583968074889,
@@ -200,7 +200,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
         -52.116212719435566,
         1017.7040292314994,
         72.00354123874057,
-        7.140121147903709,
+        7.140121147903702,
         34.24774851152607,
         -102.24646124346252,
         -543.698445859984,
@@ -211,7 +211,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
     ],
     "bound_correction_unif_resample": [
         79.60197400323416,
-        9075.812942413004,
+        9075.81294241299,
         -443.0425148340509,
         -449.63233155751726,
         15.221583968074889,
@@ -226,7 +226,7 @@ BBOB_2D_PER_MODULE_20_ITER = {
         -52.116212719435566,
         1017.7040292314994,
         72.00354123874057,
-        7.140121147903709,
+        7.140121147903702,
         34.24774851152607,
         -102.24646124346252,
         -543.698445859984,
@@ -313,32 +313,6 @@ BBOB_2D_PER_MODULE_20_ITER = {
         13.582863728801364,
         116.76955516252966,
     ],
-    "mirrored_mirrored": [
-        79.49271732413378,
-        -3.9902436014381237,
-        -449.43912237059925,
-        -454.76923415255794,
-        -5.716753396809776,
-        38.656680881133425,
-        92.96068633887359,
-        149.4276007295378,
-        124.29995348854516,
-        496.9430991621704,
-        5774.525239039822,
-        10810.490466468276,
-        65.01376333683325,
-        -52.14160901603763,
-        1016.7839906734483,
-        77.37715351910123,
-        -0.08317538023811721,
-        71.41166512690214,
-        -101.99373657488567,
-        -545.1782424507006,
-        42.700744146686965,
-        -999.5409569330642,
-        16.018941166090844,
-        118.76164430789493,
-    ],
     "mirrored_mirrored pairwise": [
         79.49271732413378,
         -3.9902436014381237,
@@ -365,6 +339,32 @@ BBOB_2D_PER_MODULE_20_ITER = {
         11.36066981667674,
         120.60256772763952,
     ],
+    "mirrored_mirrored": [
+        79.49271732413378,
+        -3.9902436014381237,
+        -449.43912237059925,
+        -454.76923415255794,
+        -5.716753396809776,
+        38.656680881133425,
+        92.96068633887359,
+        149.4276007295378,
+        124.29995348854516,
+        496.9430991621704,
+        5774.525239039822,
+        10810.490466468276,
+        65.01376333683325,
+        -52.14160901603763,
+        1016.7839906734483,
+        77.37715351910123,
+        -0.08317538023811721,
+        71.41166512690214,
+        -101.99373657488567,
+        -545.1782424507006,
+        42.700744146686965,
+        -999.5409569330642,
+        16.018941166090844,
+        118.76164430789493,
+    ],
     "orthogonal_True": [
         80.07173193213463,
         -25.0810474775418,
@@ -392,30 +392,30 @@ BBOB_2D_PER_MODULE_20_ITER = {
         119.86000340058254,
     ],
     "sequential_True": [
-        81.42670307730923,
-        -197.03460133734959,
-        -440.14992398127674,
-        -451.12732572736394,
-        -13.291945048225214,
-        6076.981902969733,
-        94.95355998430679,
-        149.29642394250206,
-        124.1297597307256,
-        4971732.424278931,
-        12676599.493062815,
-        10404.44386051647,
-        57.21633319868311,
-        -48.17074308306809,
-        1014.2663105715213,
-        75.88548853703115,
-        -1.9949361760935211,
-        5.935574663612218,
-        -101.06186715149457,
-        -543.698445859984,
+        83.26223403453476,
+        117512.71823407112,
+        -443.0425148340509,
+        -449.63233155751726,
+        23.133202262711286,
+        10389.813539761111,
+        97.60995333434538,
+        149.3343488478487,
+        127.59393177390666,
+        7694330.796085853,
+        17017375.25140306,
+        4597655.93725784,
+        76.81564795511831,
+        -47.55613893161405,
+        1025.8209383489839,
+        77.72987263145716,
+        7.988026029647063,
+        73.98356807373503,
+        -100.19493286681244,
+        -544.9528467594567,
         42.700744146686965,
-        -999.9194766573045,
-        16.134216067911535,
-        120.60256772763944,
+        -999.39715508158,
+        18.64162794684728,
+        121.36057695184782,
     ],
     "step_size_adaptation_csa": [
         79.60197400323416,
@@ -443,60 +443,164 @@ BBOB_2D_PER_MODULE_20_ITER = {
         13.582863728801364,
         116.76955516252966,
     ],
-    "step_size_adaptation_msr": [
-        79.55182029831956,
-        20022.886653199315,
-        -442.3568666516263,
-        -458.5878553497072,
-        18.230224667407526,
-        3437.0948931697662,
+    "step_size_adaptation_lp-xnes": [
+        79.60059107122254,
+        1156.2973035672185,
+        -444.90820695481506,
+        -448.94358552780955,
+        -36.4848051463744,
+        8358.025517299127,
+        92.9460091559011,
+        149.7493269470448,
+        124.04952799814593,
+        2621.0381521404584,
+        1495208.493849278,
+        5626.592106895178,
+        62.31859253339392,
+        -52.32649247097711,
+        1010.1744131780363,
+        72.09734755535143,
+        -15.912959021956848,
+        32.30960255054117,
+        -102.34645248406176,
+        -544.3080167220543,
+        42.749007493000086,
+        -999.7029654400319,
+        22.669115494695657,
+        113.67506020056967,
+    ],
+    "step_size_adaptation_m-xnes": [
+        79.55906633738796,
+        4386.41620419817,
+        -440.14992398127674,
+        -460.98138016361116,
+        16.40228675582609,
+        41.770782199901596,
         93.54091559010935,
-        149.24566420464936,
+        149.3001510889701,
         123.88066647543144,
-        745.4050969158611,
-        21842.10615574948,
-        2306430.0628835405,
-        48.237613840872996,
-        -51.65799097458237,
+        18684.968308009655,
+        128482.83441910103,
+        1281857.3005289235,
+        44.362127255980496,
+        -50.98280710710338,
         1017.7040292314994,
-        71.36065658286809,
-        3.729454150250728,
-        -9.62302556384418,
-        -102.18595163861995,
-        -543.8419319880991,
+        71.81002578700317,
+        -14.500528708427396,
+        -6.233462492224653,
+        -102.10176326857986,
+        -544.1923846845665,
         42.700744146686965,
-        -999.8834332320595,
-        15.102687676216153,
-        114.74534644305785,
+        -999.9963799088132,
+        9.561553063179554,
+        112.87464428268412,
+    ],
+    "step_size_adaptation_msr": [
+        79.54244003306202,
+        -118.26581009548049,
+        -440.14992398127674,
+        -455.4835960403074,
+        18.736041419360657,
+        3605.4061633764236,
+        93.54091559010935,
+        149.26601857625818,
+        123.88066647543144,
+        -21.626275737512415,
+        58043.62661894809,
+        2620394.1433755127,
+        44.362127255980496,
+        -51.667675482694605,
+        1017.7040292314994,
+        72.26712789062267,
+        -7.438752386989677,
+        15.992223171740047,
+        -102.10176326857986,
+        -543.8534185721645,
+        42.700744146686965,
+        -999.9068914798465,
+        9.561553063179554,
+        112.57452019629068,
+    ],
+    "step_size_adaptation_psr": [
+        79.52102181383879,
+        -43.91160560551333,
+        -441.11726502191607,
+        -456.56128813648616,
+        17.849839938781177,
+        3694.7014049597274,
+        93.54091559010935,
+        149.26690941710297,
+        123.88066647543144,
+        1913.6658308753742,
+        148364.03186841556,
+        2676492.5753466967,
+        44.362127255980496,
+        -51.62579424252932,
+        1017.7040292314994,
+        72.30933289942361,
+        -14.511086097928466,
+        43.86640712845018,
+        -102.10176326857986,
+        -544.024382872537,
+        42.700744146686965,
+        -999.945912328108,
+        9.561553063179554,
+        112.87464428268412,
     ],
     "step_size_adaptation_tpa": [
-        79.5538591212953,
-        -141.94345328377693,
+        79.55308020971381,
+        -207.50259603890402,
         -440.14992398127674,
-        -458.5878553497072,
-        4.962627005713351,
-        6828.313541466857,
+        -458.57288088617247,
+        5.4741183447131725,
+        6560.528235059466,
         93.54091559010935,
-        149.6694297943688,
-        123.88066647543144,
-        49.984511609200496,
-        808213.8882862442,
-        14527.46183219469,
-        77.93028995072423,
-        -51.04722546877122,
-        1013.9675706102718,
-        77.79736868596385,
-        4.187110321889211,
-        -5.108167534192148,
-        -102.10176326857986,
-        -543.8179322418812,
-        42.65828050834767,
+        149.65559838973334,
+        123.87243680449797,
+        233.45934327394536,
+        1016974.9297563785,
+        23982.268064532716,
+        79.31957554796386,
+        -51.0613012456259,
+        1017.7040292314994,
+        74.72824129498854,
+        2.558947945699611,
+        83.81239421766517,
+        -102.15624729506743,
+        -543.8204123260658,
+        42.65562681704674,
         -999.8888868157063,
-        15.102687676216153,
-        117.28401550404162,
+        15.715875189059393,
+        113.50420157724996,
+    ],
+    "step_size_adaptation_xnes": [
+        79.52868923287008,
+        177.2921188004035,
+        -446.3366142028796,
+        -457.76830870934236,
+        7.460165563308379,
+        458.5247153830321,
+        93.54091559010935,
+        149.45732280899628,
+        123.88066647543144,
+        326.56650297189964,
+        86.90556172988374,
+        267979.67340446153,
+        77.00389803635447,
+        -52.16277774524084,
+        1017.5812992339265,
+        74.05900952761623,
+        -1.0401150483872836,
+        -15.049763678473477,
+        -102.19153553838316,
+        -544.0421116229078,
+        42.700744146686965,
+        -999.7036847182642,
+        16.574926415489365,
+        117.94855761761136,
     ],
     "threshold_convergence_True": [
-         79.5493946792015,
+        79.5493946792015,
         -205.8874080989055,
         -440.3860520213715,
         -454.59404450938604,
